@@ -11,14 +11,14 @@ Under Windows, where the escapes are not supported it does use the Windows API.
 The colored output is generated only when the console is a terminal supporting it, so if you redirect the output to a log file you will not see the escape codes in the file.
 
 >>> import colorer, logging
->>> logging.error("red line")
->>> logging.warn("yellow line")
->>> logging.info("gray line")
->>> logging.debug("magenta line")
+... logging.error("red line")
+... logging.warn("yellow line")
+... logging.info("gray line")
+... logging.debug("magenta line")
 """
-import logging, sys
+import logging, sys, os
 
-if hasattr(sys.stderr, "isatty") and sys.stderr.isatty():
+if (hasattr(sys.stderr, "isatty") and sys.stderr.isatty()) or ('TERM' in os.environ.keys() and os.environ['TERM'] in ['linux'] ):
 	# Why stderr and not stdout? - because python logging module does output to stderr by default and not stdout.
 	# now we patch Python code to add color support to logging.StreamHandler
 	def add_coloring_to_emit_windows(fn):
@@ -126,6 +126,20 @@ if __name__ == '__main__':
 	import logging
 	# import colorer
 	# remember that logging outputs to stderr and not stdout (just in case you'll wonder)
+
+	for param in os.environ.keys():
+		print("%25s %s" % (param,os.environ[param]))
+
+	isatty = None
+	if hasattr(sys.stderr, "isatty"):
+		isatty = sys.stderr.isatty()
+	print("sys.stderr.isatty = %s" % isatty)
+
+	isatty = None
+	if hasattr(sys.stdout, "isatty"):
+		isatty = sys.stdout.isatty()
+	print("sys.stdout.isatty = %s" % isatty)
+
 	logging.getLogger().setLevel(logging.NOTSET)
 	logging.warn("a warning")
 	logging.error("some error")
